@@ -56,7 +56,6 @@ $.extend(cm, {
 				,minSize              : 50
 				,center__onresize     : ["resizeInner", _]
 				,resizerDblClickToggle: false
-				,resizerTip           : ""
 			});
 		}
 		
@@ -148,7 +147,6 @@ $.extend(cm, {
 				,minSize              : 50
 				,center__onresize     : ["resizeInner", _]
 				,resizerDblClickToggle: false
-				,resizerTip           : ""
 			});
 		}
 		
@@ -176,6 +174,9 @@ $.extend(cm, {
 			// Get tree data
 			if((_.getTree) && ((typeof (_.getTree)) == "function")){
 				// Set function getData for tree
+				/** Bug_29 */
+				tree.append($("<div class='tree-loading'></div>"));
+				/***********/
 				var tree_data = _.getTree();
 			}else{
 				return;
@@ -234,7 +235,6 @@ $.extend(cm, {
 				,minSize              : 50
 				,center__onresize     : ["resizeInner", _]
 				,resizerDblClickToggle: false
-				,resizerTip           : ""
 			});
 		}
 		
