@@ -192,30 +192,55 @@ var cm = {
 			,level : __.LEVEL_ERROR
 		});
 	}
-	,/*
-	 * Replace URL With HTML Links in text
-	 */
-	replaceUrlWithHtmlLinks : function(text, new_tab) {
-		if (text) {
-			var exp = /(&lt;|&gt;)/ig;
-			var strReplace = " $1";
-			text = text.replace(exp, strReplace);
-
-			exp = /(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#$()'*{}`\[\]\\"^\/%?=~_|!:,.;]*[-A-Z0-9+&@#$()'*{}`\[\]\\"^\/%?=~_|])/ig;
-			if (new_tab) {
-				strReplace = "<a href='$1' target='_blank' >$1</a>";
-			} else {
-				strReplace = "<a href='$1'>$1</a>";
-			}
-			text = text.replace(exp, strReplace);
-
-			exp = /( &lt;)/ig;
-			strReplace = "&lt;";
-			text = text.replace(exp, strReplace);
-			exp = /( &gt;)/ig;
-			strReplace = "&gt;";
-			text = text.replace(exp, strReplace);
-		}
-		return text;
-	}
+    
+    ,/*
+    * Replace URL With HTML Links in text
+    */
+    replaceUrlWithHtmlLinks: function(text, new_tab) {
+        if (text) {
+            var exp = /(&lt;|&gt;)/ig;
+            var strReplace = " $1";
+            text = text.replace(exp, strReplace);
+            
+            exp = /(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#$()'*{}`\[\]\\"^\/%?=~_|!:,.;]*[-A-Z0-9+&@#$()'*{}`\[\]\\"^\/%?=~_|])/ig;
+            if (new_tab) {
+                strReplace = "<a href='$1' target='_blank' >$1</a>";
+            } else {
+                strReplace = "<a href='$1'>$1</a>";
+            }
+            text = text.replace(exp, strReplace);
+            
+            exp = /( &lt;)/ig;
+            strReplace = "&lt;";
+            text = text.replace(exp, strReplace);
+            exp = /( &gt;)/ig;
+            strReplace = "&gt;";
+            text = text.replace(exp, strReplace);
+        }
+        return text;
+    }
+    ,/*
+    * Get key of node in tree
+    */
+    getNodeKey : function getNodeKey(node, facility_id) {
+        if (node.facilityId == facility_id){
+            if (node.children.length > 0) {
+                return node.key;
+            } else {
+                return;
+            }
+        } else {
+            var key;
+            $.each(node.children, function() {
+                key = getNodeKey(this, facility_id);
+                if (typeof key != 'undefined') {
+                    return false;
+                }
+            });
+            
+            if (typeof key != 'undefined') {
+                return key;
+            }
+        }
+    }
 };
\ No newline at end of file
