@@ -35,7 +35,6 @@ var fn = function(_view){
 			if(!(vw_dtl = _pers["job_detail"])){
 				return;
 			}
-			
 			// Update data for view detail
 			vw_dtl.updateData({session_id: session_id});
 		}
@@ -93,6 +92,7 @@ var fn = function(_view){
 									
 									var row_id = $(in_history[0]).parent().attr('id');
 									grid.jqGrid('setSelection',row_id);
+									_.updateJobDetail(curent_session_id);
 								}
 							}
 						}
@@ -100,7 +100,6 @@ var fn = function(_view){
 							var i     = this
 							,row_data = $(i).getRowData(row_id)
 							;
-							
 							_.updateJobDetail($.jgrid.htmlEncode(row_data.sessionId));
 						}
 					});
@@ -166,6 +165,7 @@ var fn = function(_view){
 							,{
 								text  : __.getLang("cancel")
 								,click: function(){
+									_.filter.storeValues();
 									$(this).dialog("close");
 								}
 							}
