@@ -75,7 +75,7 @@ var fn = function(_view){
 		 */
 		updateData: function(){
 			var _ = this;
-			
+
 			// call reloadGrid function 
 			if (!(_.load_flg)) {
 				_.load_flg = true;
@@ -91,7 +91,6 @@ var fn = function(_view){
 			,session_id = _view.__session_id
 			,grid       = _.grid
 			;
-			
 			// Case updating
 			_.session_id = session_id;
 			
@@ -100,7 +99,6 @@ var fn = function(_view){
 			
 			// Clear selection
 			grid.resetSelection();
-			
 			// Check to clear?
 			if(session_id === ""){
 				grid.clearGridData();
@@ -108,10 +106,10 @@ var fn = function(_view){
 				// Clear data of views which belong this view
 				_.updateNodeDetail("", "", "");
 				_.updateForwardFile("", "", "");
-				_.load_flg = false;
+                _.load_flg = false;
 				return;
 			}
-			
+			$("#load_grid_jobmanagement_job_detail").show();
 			// Reload grid
 			grid.refreshData({sessionId: session_id});
 		}
@@ -183,9 +181,13 @@ var fn = function(_view){
 						}
 						,loadComplete   : function(){
 							var session_id = _view.__session_id;
+							// Job[NodeDetail] and Job[ForwardFile] after 
+							// Job[JobDetail] loaded
+							
 							// Clear data of views which belong this view
-							//_.updateNodeDetail("", "", "");
+                            //_.updateNodeDetail("", "", "");
 							//_.updateForwardFile("", "", "");
+
 							var curent_session_id = _pers["node_detail"].__session_id;
 							var curent_jobunit_id = _pers["node_detail"].__jobunit_id;
 							var curent_job_id     = _pers["node_detail"].__job_id;
@@ -193,7 +195,7 @@ var fn = function(_view){
 							if (curent_jobunit_id !== undefined && curent_jobunit_id.length > 0
 								&& curent_session_id !== undefined && curent_session_id.length > 0
 								&& curent_job_id !== undefined && curent_job_id.length > 0) {
-								
+                            
 								var in_job_detail = $(grid).find('tr').filter(function(){
 									return ($(this).find('td:nth-child(5)').first().text() == curent_job_id && 
 											$(this).find('td:nth-child(7)').first().text() == curent_jobunit_id);
@@ -205,6 +207,8 @@ var fn = function(_view){
 								if (curent_session_id == _.session_id && in_job_detail.length > 0) {
 									var row_id = $(in_job_detail[0]).attr('id');
 									grid.jqGrid('setSelection',row_id);
+									_.updateNodeDetail(curent_session_id, curent_job_id, curent_jobunit_id);
+									_.updateForwardFile(curent_session_id, curent_job_id, curent_jobunit_id);
 								}
 							}
 							
