@@ -21,6 +21,9 @@ PURPOSE.  See the GNU General Public License for more details.
 var fn = function(){
 	var __ = cm
 	,_pers = this
+	/** Bug_154 */
+	,load_tree = false
+	/***********/
 	;
 	
 	
@@ -93,6 +96,12 @@ var fn = function(){
 				}
 				,error   : __.loadDataError
 			});
+			/** Bug_154 */
+			if(load_tree == false)
+			{
+				load_tree = _.update(_);
+			}
+			/***********/
 		}
 		
 		,/*
@@ -102,6 +111,20 @@ var fn = function(){
 			return _pers.job_tree.get();
 		}
 		
+		,
+		/** Bug_154 */
+		/*
+		 * Update data for tree 
+		 */
+		update: function(_){
+			
+			__.jobmanagement.list.content.tree.append($("<div class='tree-loading'></div>"));
+			_pers.job_tree.getData();
+			
+			return true;
+		}
+		/***********/
+		
 		,/*
 		 * Bind some action
 		 */
