@@ -135,9 +135,13 @@ var fn = function (_view){
 							});
 							
 							// Disable button "detail"
-							_.$btns.children("#detail").attr("disabled", true);
-							_.$btns.children("#confirmed").attr("disabled", true);
-							
+							if(grid.getGridParam("selarrrow").length != 1) {
+								_.$btns.children("#detail").attr("disabled", true);
+							}
+							// Disable button "confirmed"
+							if(_.getRowsUnconfirmed().length <= 0){
+								_.$btns.children("#confirmed").attr("disabled", true);
+							}
 							// Set priority bar
 							_.setPriorityStatusBar();
 						}
@@ -215,7 +219,7 @@ var fn = function (_view){
 							grid.onclick_row_id = row_id;
 							
 							// Check for setting status  of detail button
-							if(length > 1){
+							if(length != 1){
 								$btns.children("#detail").attr("disabled", true);
 							}else{
 								// Actually, length = 1, because when the action
@@ -247,7 +251,7 @@ var fn = function (_view){
 						}
 					});
 					
-					grid.processData(data_respond);
+					grid.processData(data_respond, ['monitorId', 'pluginId', 'facilityId', 'receiveTime']);
 					grid.hideCol("cb"); // Hide check box
 					grid.controlSize();
 					
@@ -278,13 +282,13 @@ var fn = function (_view){
 								}else{
 									$mn.children("#confirmed").addClass("ui-state-disabled");
 								}
-								
-								// Check for setting status of detail button
-								if(selrows.length != 1){
-									$mn.children("#detail").addClass("ui-state-disabled");
-								} else {
-									$mn.children("#detail").removeClass("ui-state-disabled");
-								}
+                                
+                                if(grid.getGridParam("selarrrow").length != 1) {
+                                    $mn.children("#detail").addClass("ui-state-disabled");
+                                }else{
+                                    $mn.children("#detail").removeClass("ui-state-disabled");
+                                }
+                                
 								return true;
 							}
 							,container   : grid.$ctn
@@ -318,10 +322,10 @@ var fn = function (_view){
 			var _ = this;
 			
 			_.tree.refreshData(tree);
-			
+			_.facility_id = "";
 			_.grid.refreshData({
 				facilityId: ""
-			});
+			}, true);
 			
 			_.setCaption("");
 		}
@@ -330,7 +334,9 @@ var fn = function (_view){
 		 * Refresh data
 		 */
 		refreshData: function(){
-			this.grid.refreshData();
+            /** Bug_11 */
+			this.grid.refreshData(null, true);
+            /***********/
 		}
 		
 		,/*
@@ -348,7 +354,7 @@ var fn = function (_view){
 					,height : 480
 					,buttons: [
 						{
-							text  : __.getLang("ok_o")
+							text  : __.getLang("cancel")
 							,click: function(){
 								$(this).dialog("close");
 							}
@@ -371,9 +377,8 @@ var fn = function (_view){
 							$(this).click(function(e){
 								var $i = $(this)
 								,$div  = $i.siblings("div:first")
-								,$title = $i.parent().siblings("td:first")
+                                ,$title = $i.parent().siblings("td:first")
 								;
-								
 								if($div.length != 0){
 									__.openTextDlg({
 										content: __.replaceUrlWithHtmlLinks($div.children("span:first").html(), true)
@@ -429,7 +434,9 @@ var fn = function (_view){
 									$.extend(post_data, {filter: true});
 									
 									// Refresh data
-									_.grid.refreshData(post_data);
+									/** Bug_11 */
+									_.grid.refreshData(post_data, true);
+									/***********/
 									// Set caption
 									_.grid.setCaption(__.getLang("filtered_list"));
 									
@@ -446,6 +453,7 @@ var fn = function (_view){
 						,{
 							text  : __.getLang("cancel")
 							,click: function(){
+								_.filter.storeValues();
 								$(this).dialog("close");
 							}
 						}
@@ -479,7 +487,9 @@ var fn = function (_view){
 			btns.children("#filter").click(function(){
 				if(_.filter_active){
 					// Inactive filter for filter grid
-					grid.refreshData({filter: false});
+					/** Bug_11 */
+					grid.refreshData({filter: false}, true);
+					/***********/
 					grid.setCaption(_._caption);
 					
 					// Process CSS for button
@@ -493,7 +503,9 @@ var fn = function (_view){
 			
 			// Bind update grid data
 			btns.children("#update").click(function(){
-				_.grid.refreshData();
+				/** Bug_11 */
+				_.grid.refreshData(null, true);
+				/***********/
 			});
 			
 			// Bind toggle left pane
@@ -508,10 +520,12 @@ var fn = function (_view){
 		getDetail: function(){
 			var _   = this
 			,grid   = _.grid
-			,row_id
+			,row_id = grid.getGridParam("selrow")
 			;
-			
-			if(row_id = grid.onclick_row_id){
+			if(row_id == null || row_id <= 0){
+				row_id = grid.onclick_row_id;
+			}	
+			if(row_id){
 				var detail = _.detail
 				,row_data  = grid.getRowData(row_id)
 				;
@@ -519,6 +533,7 @@ var fn = function (_view){
 				// Set post data
 				detail.setPostData({
 					monitorId   : $.jgrid.htmlEncode(row_data.monitorId)
+					,monitorDetailId   : $.jgrid.htmlEncode(row_data.monitorDetailId)
 					,pluginId   : $.jgrid.htmlEncode(row_data.pluginId)
 					,facilityId : $.jgrid.htmlEncode(row_data.facilityId)
 					,receiveTime: row_data.receiveTime
