@@ -62,7 +62,7 @@ var fn = function() {
 
 			$.ajax({
 				url : "get_repository_scope_list_table_define",
-				cache : false,
+				cache   : false,
 				dataType : "json",
 				type : "get",
 				success : function(data_respond) {
@@ -99,9 +99,12 @@ var fn = function() {
 						}
 					});
 
-					grid.processData(data_respond);
+					grid.processData(data_respond, ["facilityId"]);
 					grid.controlSize();
 					_.setCaption("");
+					if(pager){
+						pager.find('tbody').find('#grid_pager_repository_scope_center').width(10);
+					}
 				},
 				error : __.loadDataError
 			});
@@ -119,12 +122,13 @@ var fn = function() {
 		 */
 		resetView : function() {
 			var _ = this;
+			__.repository.scope.content.tree.append($("<div class='tree-loading'></div>"));
 
 			__.fclt_tree.getData();
-
+			_.facility_id = "";
 			_.grid.refreshData({
 				facilityId : ""
-			});
+			}, true);
 
 			_.setCaption("");
 		}
