@@ -23,6 +23,9 @@ public class Constants {
     public static final int MONITOR_SCOPE_ROW_NUM = 1000;
 
     public static final int MONITOR_STATUS_ROW_NUM = 1000;
+    
+    //max table row num for repository
+    public static final int MAX_TABLE_ROW_NUM = 1000;
 
     // Set name of repository filter node properties
     public static final String NODE_FILTER_PROPERTIES = "node_filter_properties";
